@@ -59,4 +59,13 @@ WINDOWS_LOCAL_ENV = "USERPROFILE"
 LINUX_LOCAL_ENV = "HOME"
 RENDERFARM_SDK = "renderfarm_sdk"
 
-ENGINE_TYPE = ['aspera', 'raysync']
\ No newline at end of file
+ENGINE_TYPE = ['aspera', 'raysync']
+
+PLATFORM_ALIAS_MAP = {
+            '2': 'www2',
+            '3': 'www3',
+            '6': 'www6',
+            '20': 'pic',
+            '21': 'gpu',
+            '35': 'gpu5',
+        }
\ No newline at end of file
